@@ -1193,6 +1193,8 @@ GResource *eog_exif_display_plugin_get_resource (void)
 
 */
 
+#ifndef __GTK_DOC_IGNORE__
+
 #if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)
 
 #define G_HAS_CONSTRUCTORS 1
@@ -1266,6 +1268,7 @@ GResource *eog_exif_display_plugin_get_resource (void)
 
 #endif
 
+#endif /* __GTK_DOC_IGNORE__ */
 
 #ifdef G_HAS_CONSTRUCTORS
 
