@@ -21,24 +21,15 @@
 import os
 import shutil
 
-from gi.repository import GObject, Eog, Gio, Gtk, PeasGtk
+from gi.repository import GObject, GLib, Eog, Gio, Gtk, PeasGtk
 
-
-ui_str = """
-<ui>
-    <menubar name="MainMenu">
-        <menu name="ToolsMenu" action="Tools">
-            <separator/>
-            <menuitem name="Export" action="Export"/>
-            <separator/>
-        </menu>
-    </menubar>
-</ui>
-"""
+_MENU_ID = 'Export'
+_ACTION_NAME = 'export-to-folder'
 
 EXPORT_DIR = os.path.join(os.path.expanduser('~'), 'exported-images')
 BASE_KEY = 'org.gnome.eog.plugins.export-to-folder'
 
+
 class ExportPlugin(GObject.Object, Eog.WindowActivatable):
     window = GObject.property(type=Eog.Window)
 
@@ -55,17 +46,38 @@ class ExportPlugin(GObject.Object, Eog.WindowActivatable):
         return target_dir
 
     def do_activate(self):
-        ui_manager = self.window.get_ui_manager()
-        self.action_group = Gtk.ActionGroup(name='Export')
-        self.action_group.add_actions([('Export', None,
-                        _('_Export'), "E", None, self.export_cb)], self.window)
-        ui_manager.insert_action_group(self.action_group, 0)
-        self.ui_id = ui_manager.add_ui_from_string(ui_str)
+        model = self.window.get_gear_menu_section('plugins-section')
+        action = Gio.SimpleAction.new(_ACTION_NAME)
+        action.connect('activate', self.export_cb, self.window)
+
+        self.window.add_action(action)
+        menu = Gio.Menu()
+        menu.append(_('_Export'), 'win.export-to-folder')
+        item = Gio.MenuItem.new_section(None, menu)
+        item.set_attribute([('id', 's', _MENU_ID)])
+        model.append_item(item)
+
+        # Add accelerator key
+        app = Eog.Application.get_instance()
+        app.set_accels_for_action('win.' + _ACTION_NAME, ['E', None])
 
     def do_deactivate(self):
-        ui_manager = self.window.get_ui_manager().remove_ui(self.ui_id);
+        menu = self.window.get_gear_menu_section('plugins-section')
+        for i in range(0, menu.get_n_items()):
+            value = menu.get_item_attribute_value(i, 'id',
+                                                  GLib.VariantType.new('s'))
 
-    def export_cb(self, action, window):
+            if value and value.get_string() == _MENU_ID:
+                menu.remove(i)
+                break
+
+        # Disable accelerator key
+        app = Eog.Application.get_instance()
+        app.set_accels_for_action('win.' + _ACTION_NAME, ['E', None])
+
+        self.window.remove_action(_ACTION_NAME)
+
+    def export_cb(self, action, parameter, window):
         # Get path to current image.
         image = window.get_image()
         if not image:
@@ -100,9 +112,9 @@ class ExportConfigurable(GObject.Object, PeasGtk.Configurable):
 
         self.export_dir_button = builder.get_object('export_dir_button')
         self.preferences_dialog = builder.get_object('preferences_box')
-        target_dir =  self.settings.get_string('target-folder')
+        target_dir = self.settings.get_string('target-folder')
         if target_dir == "":
-            target_dir = EXPORT_DIR;
+            target_dir = EXPORT_DIR
         self.export_dir_button.set_current_folder(target_dir)
 
         return self.preferences_dialog
